==> core-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/LazyStringValueOptions.java <==
package software.amazon.awscdk.core;

/**
 * Options for creating a lazy string token.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:46.918Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LazyStringValueOptions extends software.amazon.jsii.JsiiSerializable {
    /**
     * Use the given name as a display hint.
     * 
     * Default: - No hint
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDisplayHint();

    /**
     * @return a {@link Builder} of {@link LazyStringValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link LazyStringValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.String displayHint;

        /**
         * Sets the value of DisplayHint
         * @param displayHint Use the given name as a display hint.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder displayHint(java.lang.String displayHint) {
            this.displayHint = displayHint;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LazyStringValueOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public LazyStringValueOptions build() {
            return new Jsii$Proxy(displayHint);
        }

    }

    /**
     * An implementation for {@link LazyStringValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LazyStringValueOptions {
        private final java.lang.String displayHint;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.displayHint = this.jsiiGet("displayHint", java.lang.String.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String displayHint) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.displayHint = displayHint;
        }

        @Override
        public java.lang.String getDisplayHint() {
            return this.displayHint;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getDisplayHint() != null) {
                obj.set("displayHint", om.valueToTree(this.getDisplayHint()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LazyStringValueOptions.Jsii$Proxy that = (LazyStringValueOptions.Jsii$Proxy) o;

            return this.displayHint != null ? this.displayHint.equals(that.displayHint) : that.displayHint == null;
        }

        @Override
        public int hashCode() {
            int result = this.displayHint != null ? this.displayHint.hashCode() : 0;
            return result;
        }

    }
}

==> core-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/LazyStringValueOptions.java <==
package software.amazon.awscdk.core;

/**
 * Options for creating a lazy string token.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:35.468Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LazyStringValueOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Use the given name as a display hint.
     * 
     * Default: - No hint
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDisplayHint();

    /**
     * @return a {@link Builder} of {@link LazyStringValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LazyStringValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String displayHint;

        /**
         * Sets the value of DisplayHint
         * @param displayHint Use the given name as a display hint.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder displayHint(java.lang.String displayHint) {
            this.displayHint = displayHint;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LazyStringValueOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public LazyStringValueOptions build() {
            return new Jsii$Proxy(displayHint);
        }
    }

    /**
     * An implementation for {@link LazyStringValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LazyStringValueOptions {
        private final java.lang.String displayHint;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.displayHint = this.jsiiGet("displayHint", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String displayHint) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.displayHint = displayHint;
        }

        @Override
        public java.lang.String getDisplayHint() {
            return this.displayHint;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getDisplayHint() != null) {
                obj.set("displayHint", om.valueToTree(this.getDisplayHint()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LazyStringValueOptions.Jsii$Proxy that = (LazyStringValueOptions.Jsii$Proxy) o;

            return this.displayHint != null ? this.displayHint.equals(that.displayHint) : that.displayHint == null;
        }

        @Override
        public int hashCode() {
            int result = this.displayHint != null ? this.displayHint.hashCode() : 0;
            return result;
        }
    }
}
